Crate sansio_bootstrap

Crate sansio_bootstrap 

The helpful bootstrap APIs which enable an easy implementation of typical client side and server side pipeline initialization.

Structs

BootstrapTcpClient
A Bootstrap that makes it easy to bootstrap a pipeline to use for TCP clients.
BootstrapTcpServer
A Bootstrap that makes it easy to bootstrap a pipeline to use for TCP servers.
BootstrapUdpClient
A Bootstrap that makes it easy to bootstrap a pipeline to use for UDP clients.
BootstrapUdpServer
A Bootstrap that makes it easy to bootstrap a pipeline to use for UDP servers.

Type Aliases

PipelineFactoryFn
Creates a new RcPipeline